<p align='center'>
    <img src="https://user-images.githubusercontent.com/47505116/215187622-ea13d72c-178d-48bb-aba4-1398abf3347d.png" alt="Sushi logo">
    <br/><br/>
    <img src="https://img.shields.io/pypi/dm/sushipy.svg" alt="Downloads Badge"/>
    <br/>
    <img src="https://sonarcloud.io/api/project_badges/measure?project=dev-sushi_sushi&metric=security_rating" alt="Sonar security rating"/>
    <img src="https://sonarcloud.io/api/project_badges/measure?project=dev-sushi_sushi&metric=sqale_rating" alt="Sonar maintainability rating"/>
    <img src="https://sonarcloud.io/api/project_badges/measure?project=dev-sushi_sushi&metric=reliability_rating" alt="Sonar reliability rating"/>
</p>

---

Sushi is a library that allows you to run functions from other languages without needing to translate the code.

## How it works

Sushi compiles or interprets the code to create a runnable file which then can be executed, displaying the output in the terminal. Removing the translation step allows for code to run at its native language speed.

## Contributing

If you would like to contribute, here is a common recommended method:

1. Fork the repository on GitHub.
2. Clone your fork to your local machine.
3. Create a new branch for your changes.
4. Make any changes you want to the code or documentation.
5. Push the changes to your fork on GitHub.
6. Submit a pull request (be sure to include a good description of your changes!)

## Wiki

The wiki is currently hosted [here](dev-sushi.github.io/docs/).

## License

Sushi is licensed under the MIT license.
